# About Esssans

## Development

Esssans is an open source project by the [European Spallation Source ERIC](https://europeanspallationsource.se/) (ESS).

## License

Esssans is available as open source under the [BSD-3 license](https://opensource.org/licenses/BSD-3-Clause).

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/esssans/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

Esssans is hosted and developed [on GitHub](https://github.com/scipp/esssans).
